@@ -19,7 +19,6 @@
 #include <KSharedConfig>
 
 #include "CPUEntry.h"
-#include "BitEntry.h"
 #include "GraphicsPlatformEntry.h"
 #include "GPUEntry.h"
 #include "KernelEntry.h"
@@ -184,7 +183,6 @@ void Module::loadEntries()
                          new Entry(ki18n("KDE Frameworks Version:"), KCoreAddons::versionString()),
                          new Entry(ki18n("Qt Version:"), QString::fromLatin1(qVersion())),
                          new KernelEntry(),
-                         new BitEntry(),
                          new GraphicsPlatformEntry()
                      });
 
