@@ -309,7 +309,7 @@ mesa_hack(Display *dpy, int scrnum)
       GLX_ACCUM_BLUE_SIZE, 1,
       GLX_ACCUM_ALPHA_SIZE, 1,
       GLX_DOUBLEBUFFER,
-      None
+      None,
    };
    XVisualInfo *visinfo;
 
@@ -414,7 +414,7 @@ print_limits(QTreeWidgetItem *l1, const char * glExtensions, bool getProcAddress
 #ifdef GL_MAX_PALETTE_MATRICES_ARB
       { 1, GL_MAX_PALETTE_MATRICES_ARB, i18n("Max. vertex blend matrix palette size") },
 #endif
-      {0,0,QString()}
+      {0,0,QString()},
      };
 
    const struct token_name texture_limits[] = {
@@ -428,7 +428,7 @@ print_limits(QTreeWidgetItem *l1, const char * glExtensions, bool getProcAddress
       { 1 | KCMGL_FLOAT, GL_MAX_TEXTURE_LOD_BIAS_EXT, i18n("Max. texture LOD bias") },
       { 1, GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT, 	i18n("Max. anisotropy filtering level") },
       { 1, GL_NUM_COMPRESSED_TEXTURE_FORMATS_ARB, i18n("No. of compressed texture formats") },
-      {0,0,QString()}
+      {0,0,QString()},
      };
 
    const struct token_name float_limits[] = {
@@ -438,7 +438,7 @@ print_limits(QTreeWidgetItem *l1, const char * glExtensions, bool getProcAddress
       { 2 | KCMGL_FLOAT, GL_ALIASED_LINE_WIDTH_RANGE, 	"ALIASED_LINE_WIDTH_RANGE" },
       { 2 | KCMGL_FLOAT, GL_SMOOTH_LINE_WIDTH_RANGE, 	"SMOOTH_LINE_WIDTH_RANGE" },
       { 1 | KCMGL_FLOAT, GL_SMOOTH_LINE_WIDTH_GRANULARITY,"SMOOTH_LINE_WIDTH_GRANULARITY"},
-      {0,0,QString()}
+      {0,0,QString()},
      };
 
    const struct token_name stack_depth[] = {
@@ -452,7 +452,7 @@ print_limits(QTreeWidgetItem *l1, const char * glExtensions, bool getProcAddress
 #ifdef GL_MAX_MATRIX_PALETTE_STACK_DEPTH_ARB
       { 1, GL_MAX_MATRIX_PALETTE_STACK_DEPTH_ARB,"MAX_MATRIX_PALETTE_STACK_DEPTH"},
 #endif
-      {0,0,QString()}
+      {0,0,QString()},
    };
 
 #ifdef GL_ARB_fragment_program
@@ -477,7 +477,7 @@ print_limits(QTreeWidgetItem *l1, const char * glExtensions, bool getProcAddress
     { 1 | KCMGL_PROG, GL_MAX_PROGRAM_NATIVE_TEMPORARIES_ARB, "MAX_PROGRAM_NATIVE_TEMPORARIES" },
     { 1 | KCMGL_PROG, GL_MAX_PROGRAM_NATIVE_PARAMETERS_ARB, "MAX_PROGRAM_NATIVE_PARAMETERS" },
     { 1 | KCMGL_PROG, GL_MAX_PROGRAM_NATIVE_ATTRIBS_ARB, "MAX_PROGRAM_NATIVE_ATTRIBS" },
-    {0,0,QString()}
+    {0,0,QString()},
    };
 #endif
 
@@ -498,7 +498,7 @@ print_limits(QTreeWidgetItem *l1, const char * glExtensions, bool getProcAddress
 { 1 | KCMGL_PROG, GL_MAX_PROGRAM_NATIVE_PARAMETERS_ARB,"MAX_PROGRAM_NATIVE_PARAMETERS"},
 { 1 | KCMGL_PROG, GL_MAX_PROGRAM_NATIVE_ATTRIBS_ARB,"MAX_PROGRAM_NATIVE_ATTRIBS"},
 { 1 | KCMGL_PROG, GL_MAX_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB ,"MAX_PROGRAM_NATIVE_ADDRESS_REGISTERS"},
-{0,0,QString()}
+{0,0,QString()},
 };
 #endif
 
@@ -511,7 +511,7 @@ print_limits(QTreeWidgetItem *l1, const char * glExtensions, bool getProcAddress
     { 1, GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS_ARB,"MAX_VERTEX_TEXTURE_IMAGE_UNITS"},
     { 1, GL_MAX_TEXTURE_IMAGE_UNITS_ARB,"MAX_TEXTURE_IMAGE_UNITS"},
     { 1, GL_MAX_TEXTURE_COORDS_ARB,"MAX_TEXTURE_COORDS"},
-    {0,0,QString()}
+    {0,0,QString()},
    };
 #endif
 
@@ -520,7 +520,7 @@ print_limits(QTreeWidgetItem *l1, const char * glExtensions, bool getProcAddress
     { 1, GL_MAX_FRAGMENT_UNIFORM_COMPONENTS_ARB,"MAX_FRAGMENT_UNIFORM_COMPONENTS"},
     { 1, GL_MAX_TEXTURE_IMAGE_UNITS_ARB,"MAX_TEXTURE_IMAGE_UNITS"},
     { 1, GL_MAX_TEXTURE_COORDS_ARB,"MAX_TEXTURE_COORDS"},
-    {0,0,QString()}
+    {0,0,QString()},
    };
 #endif
 
@@ -528,7 +528,7 @@ print_limits(QTreeWidgetItem *l1, const char * glExtensions, bool getProcAddress
       { 2, GL_MAX_VIEWPORT_DIMS, 	i18n("Max. viewport dimensions") },
       { 1, GL_SUBPIXEL_BITS, 		i18n("Subpixel bits") },
       { 1, GL_AUX_BUFFERS, 		i18n("Aux. buffers")},
-      {0,0,QString()}
+      {0,0,QString()},
     };
 
    const struct token_group groups[] =
@@ -632,7 +632,7 @@ static QTreeWidgetItem *print_screen_info(QTreeWidgetItem *l1, QTreeWidgetItem *
                 makeDriItem(infos.at(0), l2, nullptr);
             }
 		} else {
-            l2 = newItem(l1, l2, i18n("3D Accelerator"), i18n("unknown"));
+            l2 = newItem(l1, l2, i18nc("Just one accelerator", "3D Accelerator"), i18n("unknown"));
         }
     }
     
@@ -733,7 +733,8 @@ static QTreeWidgetItem *get_gl_info_glx(Display *dpy, int scrnum, Bool allowDire
       GLX_GREEN_SIZE, 1,
       GLX_BLUE_SIZE, 1,
       GLX_DOUBLEBUFFER,
-      None };
+      None,
+    };
    GLXContext ctx;
 
    visinfo = glXChooseVisual(dpy, scrnum, const_cast<int*>(attribSingle));
@@ -813,11 +814,11 @@ static QTreeWidgetItem *get_gl_info_egl(Display *dpy, int scrnum, QTreeWidgetIte
       EGL_GREEN_SIZE, 1,
       EGL_BLUE_SIZE, 1,
       EGL_DEPTH_SIZE, 1,
-      EGL_NONE
+      EGL_NONE,
    };
    static const EGLint ctx_attribs[] = {
       EGL_CONTEXT_CLIENT_VERSION, 2,
-      EGL_NONE
+      EGL_NONE,
    };
 
    XVisualInfo visTemplate;
